﻿//   Copyright 2023 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
namespace DisplayDeviceLocation;

using Esri.ArcGISRuntime.UI;
using System.ComponentModel;


public partial class MainPage : ContentPage
{

    public MainPage()
    {
        InitializeComponent();

        MainMapView.PropertyChanged += (object sender, PropertyChangedEventArgs e) =>
        {
            // The map view's location display is initially null, so check for a location display property change before enabling it.
            if (e.PropertyName == nameof(LocationDisplay))
            {
                _ = DisplayDeviceLocationAsync();
            }
        };

    }


    private async Task DisplayDeviceLocationAsync()
    {

        PermissionStatus status = await Permissions.RequestAsync<Permissions.LocationWhenInUse>();

        MainMapView.LocationDisplay.IsEnabled = status == PermissionStatus.Granted || status == PermissionStatus.Restricted;
        MainMapView.LocationDisplay.AutoPanMode = LocationDisplayAutoPanMode.Recenter;

    }

}
